@@ -25,7 +25,7 @@ _DEFAULT_HOOKS = [
 
 
 @nncore.bind_getter('mode', 'max_stages', 'max_epochs', 'max_iters',
-                    'start_iter', 'stage', 'epoch', 'iter')
+                    'start_iter', 'stage', 'epoch', 'iter', 'kwargs')
 class Engine(object):
     """
     An engine that can take over the whole training, validation and testing
@@ -37,10 +37,10 @@ class Engine(object):
         model (:obj:`nn.Module`): The model to be trained or tested. The
             :obj:`forward` method of the model should return a dict containing
             a ``_num_samples`` field indicating the number of samples in the
-            current batch, and optionally an ``out`` field denoting the model
+            current batch, and optionally a ``_out`` field denoting the model
             outputs to be collected and evaluated.
-        data_loaders (dict): The data loaders for training, validating and
-            testing. It should be in the format of
+        data_loaders (dict): The potential data loaders for training,
+            validation and testing. It should be in the format of
             ``dict(train=train_loader, val=val_loader, test=test_loader)``.
         stages (list[dict], dict, optional): The stage config or list of stage
             configs to be scheduled. Each stage config should be a dict
@@ -67,16 +67,16 @@ class Engine(object):
                     ``target_lr=0``. Please refer to :obj:`LrUpdaterHook` for \
                     full configs.
 
-            - `warmup` (dict, optional): The warmup policy config containing \
+            - `warmup` (dict, optional): The warm-up policy config containing \
                 the following fields:
 
-                - `type` (str): Type of the warmup schedule. Expected values \
+                - `type` (str): Type of the warm-up schedule. Expected values \
                     include ``'epoch'`` and ``'iter'``, indicating warming up \
                     for ``step`` epochs for iterations.
-                - `policy` (str): The warmup policy to use. Currently \
+                - `policy` (str): The warm-up policy to use. Currently \
                     supported policies include ``linear``, ``exp`` and \
                     ``constant``.
-                - `step` (int): Number of steps to warmup.
+                - `step` (int): Number of iterations to warm-up.
                 - `ratio` (float): The ratio of learning rate to start with. \
                     Expected values are in the range of ``0 ~ 1``.
 
@@ -112,7 +112,7 @@ class Engine(object):
         ...
         >>> # Configure stages:
         >>> # [Stage 1] Train the model for 5 epochs using Adam optimizer with
-        >>> # a fixed learning rate (1e-3) and a linear warmup policy.
+        >>> # a fixed learning rate (1e-3) and a linear warm-up policy.
         >>> # [Stage 2] Train the model for another 3 epochs using SGD with
         >>> # momentum optimizer and a iter-based cosine learning rate
         >>> # schedule. Perform validation after every training epoch.
@@ -210,7 +210,7 @@ class Engine(object):
 
     def register_hook(self, hook, before=None, overwrite=True, **kwargs):
         """
-        Register a hook into the engine.
+        Register a hook or a list of hooks into the engine.
 
         Args:
             hook (list or :obj:`Hook` or dict or str): The hook or list of
@@ -231,11 +231,14 @@ class Engine(object):
             hook = build_hook(hook, **kwargs)
         elif not isinstance(hook, Hook):
             raise TypeError(
-                "hook must be a Hook, a dict or a string, but got '{}'".format(
+                "hook must be a Hook, a dict or a str, but got '{}'".format(
                     type(hook)))
 
         if hook.name in self.hooks:
             if overwrite:
+                keys = list(self.hooks.keys())
+                if before is None and keys[-1] != hook.name:
+                    before = keys[keys.index(hook.name) + 1]
                 self.hooks.pop(hook.name)
             else:
                 raise KeyError("hook '{}' exists".format(hook.name))
@@ -247,10 +250,27 @@ class Engine(object):
                 raise ValueError("hook '{}' not found".format(before))
 
             keys = list(self.hooks.keys())
-            idx = keys.index(before)
-            for key in keys[idx:-1]:
+            for key in keys[keys.index(before):-1]:
                 self.hooks.move_to_end(key)
 
+    def unregister_hook(self, hook):
+        """
+        Unregister a hook or a list of hooks from the engine.
+
+        Args:
+            hook (list or :obj:`Hook` or str): The hook or list of hooks to be
+                unregistered. Each hook should be represented as a :obj:`Hook`
+                or a str.
+        """
+        if isinstance(hook, (list, tuple)):
+            for h in hook:
+                self.unregister_hook(h)
+            return
+
+        if isinstance(hook, Hook):
+            hook = hook.name
+        self.hooks.pop(hook)
+
     def build_optimizer(self, optimizer):
         """
         Build an optimizer for the engine.
@@ -275,8 +295,7 @@ class Engine(object):
 
         Args:
             checkpoint (dict or str): A dict, a filename, an URL or a
-                ``torchvision://<model_name>`` string indicating the
-                checkpoint.
+                ``torchvision://<model_name>`` str indicating the checkpoint.
             strict (bool, optional): Whether to allow different params for the
                 model and checkpoint. If ``True``, raise an error when the
                 params do not match exactly. Default: ``False``.
@@ -447,14 +466,14 @@ class Engine(object):
         self._call_hook('after_stage')
         self._stage += 1
 
-    def evaluate(self, key='out'):
+    def evaluate(self, key='_out'):
         """
         Perform evaluation. This methods is expected to be called after
         validation or testing.
 
         Args:
             key (str, optional): The buffer key of the values to be evaluated.
-                Default: ``'out'``.
+                Default: ``'_out'``.
         """
         blob = self.buffer.pop(key)
         blob = gather(blob)
