@@ -46,16 +46,21 @@ def _inv(base_lr, progress, gamma, power=1, **kwargs):
 @HOOKS.register()
 class LrUpdaterHook(Hook):
     """
-    Update learning rate every specified epoch or step. Currently supported
-    learning rate policies include ``step``, ``cosine``, ``exp``, ``poly`` and
-    ``inv``.
+    Update learning rate periodically during training. Currently supported
+    learning rate and warm-up policies are ``step``, ``cosine``, ``exp``,
+    ``poly``, ``inv`` and ``linear``, ``exp``, ``constant`` respectively.
 
-    Policy configs:
+    Learning rate policy configs:
         - `step`: step (list[int]), gamma (float, Default: ``0.1``)
         - `cosine`: target_lr (float, Default: ``0``)
         - `exp`: gamma (float)
         - `poly`: power (float, Default: ``1``), min_lr (float, Default: ``0``)
         - `inv`: gamma (float), power (float, Default: ``1``)
+
+    Warm-up policy configs:
+        - `linear`: ratio (float)
+        - `exp`: ratio (float)
+        - `constant`: ratio (float)
     """
 
     def _base_lr(self, engine):
@@ -79,7 +84,7 @@ class LrUpdaterHook(Hook):
         elif self._warm_cfg['policy'] == 'constant':
             scale = self._warm_cfg['ratio']
         else:
-            raise TypeError("invalid warmup policy: '{}'".format(
+            raise TypeError("invalid warm-up policy: '{}'".format(
                 self._warm_cfg['policy']))
         return [lr * scale for lr in lr_groups]
 
