@@ -2,8 +2,9 @@
 
 from .bbox import (bbox_area, bbox_intersection, bbox_iof, bbox_iou,
                    remove_small_bboxes)
+from .data import cosine_similarity
 
 __all__ = [
     'bbox_area', 'bbox_intersection', 'bbox_iof', 'bbox_iou',
-    'remove_small_bboxes'
+    'remove_small_bboxes', 'cosine_similarity'
 ]
